@@ -1,4 +1,4 @@
-// Copyright (C) 2007 Manu Garg.
+// Copyright (C) 2007-2023 Manu Garg.
 // Author: Manu Garg <manugarg@gmail.com>
 //
 // pac_utils.h defines some of the functions used by PAC files. This file is
@@ -332,40 +332,3 @@ static const char *pacUtils =
 "        return FindProxyForURL(url, host);\n"
 "    }\n"
 "}\n";
-
-
-// You must free the result if result is non-NULL.
-char *str_replace(const char *orig, char *rep, char *with) {
-    char *result;  // the return string
-    char *ins;     // the next insert point
-    char *tmp;     // varies
-    int count;     // number of replacements
-    int len_front; // distance between rep and end of last rep
-    int len_rep  = strlen(rep);
-    int len_with = strlen(with);
-
-    // Get the count of replacements
-    ins = orig;
-    for (count = 0; (tmp = strstr(ins, rep)); ++count) {
-        ins = tmp + len_rep;
-    }
-
-    tmp = result = malloc(strlen(orig) + (len_with - len_rep) * count + 1);
-
-    // first time through the loop, all the variable are set correctly
-    // from here on,
-    //    tmp points to the end of the result string
-    //    ins points to the next occurrence of rep in orig
-    //    orig points to the remainder of orig after "end of rep"
-    while (count--) {
-        ins = strstr(orig, rep);
-        len_front = ins - orig;
-        tmp = strncpy(tmp, orig, len_front) + len_front;
-        tmp = strcpy(tmp, with) + len_with;
-        orig += len_front + len_rep; // move to next "end of rep"
-    }
-
-    // Copy the remaining string.
-    strcpy(tmp, orig);
-    return result;
-}
